@@ -24,7 +24,7 @@ class AvailableProtoStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SaleStatus: 售卖状态。可选值有 sale_out 售罄、saling可售、no_saling不可销售
         :type SaleStatus: str
         :param Protocol: 协议类型。可选值有 NFS、CIFS
@@ -52,7 +52,7 @@ class AvailableRegion(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Region: 区域名称，如“ap-beijing”
         :type Region: str
         :param RegionName: 区域名称，如“bj”
@@ -97,7 +97,7 @@ class AvailableType(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Protocols: 协议与售卖详情
         :type Protocols: list of AvailableProtoStatus
         :param Type: 存储类型。返回值中 SD 为标准型存储、HP 为性能型存储
@@ -134,7 +134,7 @@ class AvailableZone(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Zone: 可用区名称
         :type Zone: str
         :param ZoneId: 可用区ID
@@ -179,22 +179,22 @@ class CreateCfsFileSystemRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Zone: 可用区名称，例如ap-beijing-1，请参考 [概览](https://cloud.tencent.com/document/product/582/13225) 文档中的地域与可用区列表
         :type Zone: str
-        :param NetInterface: 网络类型，值为 VPC，BASIC；其中 VPC 为私有网络，BASIC 为基础网络
+        :param NetInterface: 网络类型，可选值为 VPC，BASIC，CCN；其中 VPC 为私有网络，BASIC 为基础网络, CCN 为云联网，Turbo系列当前必须选择云联网。目前基础网络已逐渐淘汰，不推荐使用。
         :type NetInterface: str
-        :param PGroupId: 权限组 ID
+        :param PGroupId: 权限组 ID，通用标准型和性能型必填，turbo系列请填写pgroupbasic
         :type PGroupId: str
-        :param Protocol: 文件系统协议类型， 值为 NFS、CIFS; 若留空则默认为 NFS协议
+        :param Protocol: 文件系统协议类型， 值为 NFS、CIFS、TURBO ; 若留空则默认为 NFS协议，turbo系列必须选择turbo，不支持NFS、CIFS
         :type Protocol: str
-        :param StorageType: 文件系统存储类型，值为 SD ；其中 SD 为标准型存储， HP为性能存储。
+        :param StorageType: 文件系统存储类型，默认值为 SD ；其中 SD 为通用标准型标准型存储， HP为通用性能型存储， TB为turbo标准型， TP 为turbo性能型。
         :type StorageType: str
         :param VpcId: 私有网络（VPC） ID，若网络类型选择的是VPC，该字段为必填。
         :type VpcId: str
         :param SubnetId: 子网 ID，若网络类型选择的是VPC，该字段为必填。
         :type SubnetId: str
-        :param MountIP: 指定IP地址，仅VPC网络支持；若不填写、将在该子网下随机分配 IP
+        :param MountIP: 指定IP地址，仅VPC网络支持；若不填写、将在该子网下随机分配 IP，Turbo系列当前不支持指定
         :type MountIP: str
         :param FsName: 用户自定义文件系统名称
         :type FsName: str
@@ -202,6 +202,12 @@ class CreateCfsFileSystemRequest(AbstractModel):
         :type ResourceTags: list of TagInfo
         :param ClientToken: 用于保证请求幂等性的字符串。该字符串由客户生成，需保证不同请求之间唯一，最大值不超过64个ASCII字符。若不指定该参数，则无法保证请求的幂等性。用于保证请求幂等性的字符串失效时间为2小时。
         :type ClientToken: str
+        :param CcnId: 云联网ID， 若网络类型选择的是CCN，该字段为必填
+        :type CcnId: str
+        :param CidrBlock: 云联网中CFS使用的网段， 若网络类型选择的是Ccn，该字段为必填，且不能和Ccn中已经绑定的网段冲突
+        :type CidrBlock: str
+        :param Capacity: 文件系统容量，turbo系列必填，单位为GiB。 turbo标准型单位GB，起售40TiB，即40960 GiB；扩容步长20TiB，即20480 GiB。turbo性能型起售20TiB，即20480 GiB；扩容步长10TiB，10240 GiB。
+        :type Capacity: int
         """
         self.Zone = None
         self.NetInterface = None
@@ -214,6 +220,9 @@ class CreateCfsFileSystemRequest(AbstractModel):
         self.FsName = None
         self.ResourceTags = None
         self.ClientToken = None
+        self.CcnId = None
+        self.CidrBlock = None
+        self.Capacity = None
 
 
     def _deserialize(self, params):
@@ -233,6 +242,9 @@ class CreateCfsFileSystemRequest(AbstractModel):
                 obj._deserialize(item)
                 self.ResourceTags.append(obj)
         self.ClientToken = params.get("ClientToken")
+        self.CcnId = params.get("CcnId")
+        self.CidrBlock = params.get("CidrBlock")
+        self.Capacity = params.get("Capacity")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -248,16 +260,16 @@ class CreateCfsFileSystemResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CreationTime: 文件系统创建时间
         :type CreationTime: str
         :param CreationToken: 用户自定义文件系统名称
         :type CreationToken: str
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
-        :param LifeCycleState: 文件系统状态
+        :param LifeCycleState: 文件系统状态，可能出现状态包括：“creating”  创建中, “create_failed” 创建失败, “available” 可用, “unserviced” 不可用, “upgrading” 升级中， “deleting” 删除中。
         :type LifeCycleState: str
-        :param SizeByte: 文件系统已使用容量大小
+        :param SizeByte: 文件系统已使用容量大小，单位为 Byte
         :type SizeByte: int
         :param ZoneId: 可用区 ID
         :type ZoneId: int
@@ -297,7 +309,7 @@ class CreateCfsPGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 权限组名称，1-64个字符且只能为中文，字母，数字，下划线或横线
         :type Name: str
         :param DescInfo: 权限组描述信息，1-255个字符
@@ -325,7 +337,7 @@ class CreateCfsPGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param Name: 权限组名字
@@ -362,7 +374,7 @@ class CreateCfsRuleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param AuthClientIp: 可以填写单个 IP 或者单个网段，例如 10.1.10.11 或者 10.10.1.0/24。默认来访地址为*表示允许所有。同时需要注意，此处需填写 CVM 的内网 IP。
@@ -402,7 +414,7 @@ class CreateCfsRuleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RuleId: 规则 ID
         :type RuleId: str
         :param PGroupId: 权限组 ID
@@ -443,7 +455,7 @@ class DeleteCfsFileSystemRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID。说明，进行删除文件系统操作前需要先调用 DeleteMountTarget 接口删除该文件系统的挂载点，否则会删除失败。
         :type FileSystemId: str
         """
@@ -467,7 +479,7 @@ class DeleteCfsFileSystemResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -484,7 +496,7 @@ class DeleteCfsPGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         """
@@ -508,7 +520,7 @@ class DeleteCfsPGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param AppId: 用户 ID
@@ -533,7 +545,7 @@ class DeleteCfsRuleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param RuleId: 规则 ID
@@ -561,7 +573,7 @@ class DeleteCfsRuleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RuleId: 规则 ID
         :type RuleId: str
         :param PGroupId: 权限组 ID
@@ -586,7 +598,7 @@ class DeleteMountTargetRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
         :param MountTargetId: 挂载点 ID
@@ -614,7 +626,7 @@ class DeleteMountTargetResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -637,7 +649,7 @@ class DescribeAvailableZoneInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RegionZones: 各可用区的资源售卖情况以及支持的存储类型、存储协议等信息
         :type RegionZones: list of AvailableRegion
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -663,7 +675,7 @@ class DescribeCfsFileSystemClientsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID。
         :type FileSystemId: str
         """
@@ -687,7 +699,7 @@ class DescribeCfsFileSystemClientsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ClientList: 客户端列表
         :type ClientList: list of FileSystemClient
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -713,7 +725,7 @@ class DescribeCfsFileSystemsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
         :param VpcId: 私有网络（VPC） ID
@@ -745,7 +757,7 @@ class DescribeCfsFileSystemsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystems: 文件系统信息
         :type FileSystems: list of FileSystemInfo
         :param TotalCount: 文件系统总数
@@ -781,7 +793,7 @@ class DescribeCfsPGroupsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupList: 权限组信息列表
         :type PGroupList: list of PGroupInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -807,7 +819,7 @@ class DescribeCfsRulesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         """
@@ -831,7 +843,7 @@ class DescribeCfsRulesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RuleList: 权限组规则列表
         :type RuleList: list of PGroupRuleInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -863,7 +875,7 @@ class DescribeCfsServiceStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CfsServiceStatus: 该用户当前 CFS 服务的状态，none 为未开通，creating 为开通中，created 为已开通
         :type CfsServiceStatus: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -884,7 +896,7 @@ class DescribeMountTargetsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
         """
@@ -908,7 +920,7 @@ class DescribeMountTargetsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param MountTargets: 挂载点详情
         :type MountTargets: list of MountInfo
         :param NumberOfMountTargets: 挂载点数量
@@ -938,7 +950,7 @@ class FileSystemClient(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CfsVip: 文件系统IP地址
         :type CfsVip: str
         :param ClientIp: 客户端IP地址
@@ -982,7 +994,7 @@ class FileSystemInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CreationTime: 创建时间
         :type CreationTime: str
         :param CreationToken: 用户自定义名称
@@ -1019,6 +1031,8 @@ class FileSystemInfo(AbstractModel):
         :type AppId: int
         :param BandwidthLimit: 文件系统吞吐上限，吞吐上限是根据文件系统当前已使用存储量、绑定的存储资源包以及吞吐资源包一同确定
         :type BandwidthLimit: float
+        :param Capacity: 文件系统总容量
+        :type Capacity: int
         """
         self.CreationTime = None
         self.CreationToken = None
@@ -1038,6 +1052,7 @@ class FileSystemInfo(AbstractModel):
         self.KmsKeyId = None
         self.AppId = None
         self.BandwidthLimit = None
+        self.Capacity = None
 
 
     def _deserialize(self, params):
@@ -1061,6 +1076,7 @@ class FileSystemInfo(AbstractModel):
         self.KmsKeyId = params.get("KmsKeyId")
         self.AppId = params.get("AppId")
         self.BandwidthLimit = params.get("BandwidthLimit")
+        self.Capacity = params.get("Capacity")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1076,7 +1092,7 @@ class MountInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
         :param MountTargetId: 挂载点 ID
@@ -1097,6 +1113,10 @@ class MountInfo(AbstractModel):
         :type SubnetId: str
         :param SubnetName: 子网名称
         :type SubnetName: str
+        :param CcnID: CFS Turbo使用的云联网ID
+        :type CcnID: str
+        :param CidrBlock: 云联网中CFS Turbo使用的网段
+        :type CidrBlock: str
         """
         self.FileSystemId = None
         self.MountTargetId = None
@@ -1108,6 +1128,8 @@ class MountInfo(AbstractModel):
         self.VpcName = None
         self.SubnetId = None
         self.SubnetName = None
+        self.CcnID = None
+        self.CidrBlock = None
 
 
     def _deserialize(self, params):
@@ -1121,6 +1143,8 @@ class MountInfo(AbstractModel):
         self.VpcName = params.get("VpcName")
         self.SubnetId = params.get("SubnetId")
         self.SubnetName = params.get("SubnetName")
+        self.CcnID = params.get("CcnID")
+        self.CidrBlock = params.get("CidrBlock")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1136,7 +1160,7 @@ class PGroup(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组ID
         :type PGroupId: str
         :param Name: 权限组名称
@@ -1164,7 +1188,7 @@ class PGroupInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组ID
         :type PGroupId: str
         :param Name: 权限组名称
@@ -1204,7 +1228,7 @@ class PGroupRuleInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RuleId: 规则ID
         :type RuleId: str
         :param AuthClientIp: 允许访问的客户端IP
@@ -1250,7 +1274,7 @@ class SignUpCfsServiceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CfsServiceStatus: 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通
         :type CfsServiceStatus: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1271,7 +1295,7 @@ class TagInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TagKey: 标签键
         :type TagKey: str
         :param TagValue: 标签值
@@ -1299,7 +1323,7 @@ class UpdateCfsFileSystemNameRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSystemId: 文件系统 ID
         :type FileSystemId: str
         :param FsName: 用户自定义文件系统名称
@@ -1327,7 +1351,7 @@ class UpdateCfsFileSystemNameResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CreationToken: 用户自定义文件系统名称
         :type CreationToken: str
         :param FileSystemId: 文件系统ID
@@ -1356,7 +1380,7 @@ class UpdateCfsFileSystemPGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param FileSystemId: 文件系统 ID
@@ -1384,7 +1408,7 @@ class UpdateCfsFileSystemPGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param FileSystemId: 文件系统 ID
@@ -1409,7 +1433,7 @@ class UpdateCfsFileSystemSizeLimitRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FsLimit: 文件系统容量限制大小，输入范围0-1073741824, 单位为GB；其中输入值为0时，表示不限制文件系统容量。
         :type FsLimit: int
         :param FileSystemId: 文件系统ID，目前仅支持标准型文件系统。
@@ -1437,7 +1461,7 @@ class UpdateCfsFileSystemSizeLimitResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1454,7 +1478,7 @@ class UpdateCfsPGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param Name: 权限组名称，1-64个字符且只能为中文，字母，数字，下划线或横线
@@ -1486,7 +1510,7 @@ class UpdateCfsPGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组ID
         :type PGroupId: str
         :param Name: 权限组名称
@@ -1515,7 +1539,7 @@ class UpdateCfsRuleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param RuleId: 规则 ID
@@ -1559,7 +1583,7 @@ class UpdateCfsRuleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PGroupId: 权限组 ID
         :type PGroupId: str
         :param RuleId: 规则 ID
